<?php
/**
 * Main Admin Class
 *
 * @package     Barn2\Plugin\WC_Lead_Time\Admin
 * @subpackage  Admin
 * @author    	Barn2 Media <info@barn2.co.uk>
 * @license     GPL-3.0
 * @copyright	Barn2 Media Ltd
 */

namespace Barn2\Plugin\WC_Lead_Time\Admin;

use Barn2\Lib\Registerable;
use Barn2\Lib\Util;

// Prevent direct file access
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Admin implements Registerable {
	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
			self::$instance->register();
		}

		return self::$instance;
	}

	/**
	 * Constructor
	 */
	public function __construct() {

	}

	/**
	 * Register hooks and filters
	 */
	public function register() {
        add_filter( 'plugin_action_links_' . WCLT_PLUGIN_BASENAME, array( $this, 'plugin_action_links' ) );
		add_filter( 'plugin_row_meta', array( $this, 'plugin_page_row_meta' ), 10, 2 );

		add_action( 'admin_enqueue_scripts', array( $this, 'register_admin_scripts' ) );
	}

	public function register_admin_scripts( $hook ) {
		$min = Util::get_script_suffix();

		if ( $hook === 'woocommerce_page_wc-settings' ) {
			wp_enqueue_style( 'wclt-admin', plugins_url( "assets/css/admin/wc-lead-time-admin{$min}.css", WCLT_PLUGIN_FILE ), array(), WCLT_PLUGIN_VERSION );
		}
	}

    /**
     * Add Settings Link to Plugins page
     *
     * @since 1.0.0
     *
     * @param array $links
     * @return array $links
     */
    public function plugin_action_links( $links ) {
        array_unshift( $links, sprintf(
                '<a href="%1$s">%2$s</a>',
                admin_url( 'admin.php?page=wc-settings&tab=products&section=lead-time' ),
                __( 'Settings', 'woocommerce-lead-time' )
            )
        );

		return $links;
	}

    /**
     * Add Docs Link to Plugins page
     *
     * @param array $links
     * @param string $file
     * @return array $links
     */
	public function plugin_page_row_meta( $links, $file ) {
		if ( WCLT_PLUGIN_BASENAME === $file ) {
			$link_fmt	 = '<a href="%1$s" aria-label="%2$s" target="_blank">%3$s</a>';
			$row_meta	 = array(
				'docs' => sprintf(
                    $link_fmt,
                    esc_url( 'https://barn2.co.uk/kb-categories/woocommerce-lead-time-kb/' ),
                    esc_attr__( 'View WooCommerce Lead Time documentation', 'woocommerce-lead-time' ),
                    esc_html__( 'Docs', 'woocommerce-lead-time' )
                )
			);

			return array_merge( $links, $row_meta );
		}

		return (array) $links;
	}
}
