<?php
/**
 * WooCommerce Product Data Metabox
 *
 * @package     Barn2\Plugin\WC_Lead_Time\Admin
 * @subpackage  Product_Data
 * @author    	Barn2 Media <info@barn2.co.uk>
 * @license     GPL-3.0
 * @copyright	Barn2 Media Ltd
 */

namespace Barn2\Plugin\WC_Lead_Time\Admin;

use Barn2\Lib\Registerable;

// Prevent direct file access
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Product_Data implements Registerable {
	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {
		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
			self::$instance->register();
		}

		return self::$instance;
	}

    /**
     * Register hooks and filters
     *
     * @since 1.0.0
     */
    public function register() {
        add_action( 'woocommerce_product_options_stock_status', array( $this, 'add_field' ) );
        add_action( 'woocommerce_process_product_meta', array( $this, 'save_field' ) );
    }

    /**
     * Add the lead time field
     *
     * @since 1.0.0
     */
    public function add_field() {
        $global_lead_time = get_option( 'wclt_global_time' );

        echo '<div class="lead_time_field">';

        woocommerce_wp_text_input(
            array(
                'id'            => '_wclt_lead_time',
                'label'         => __( 'Lead time', 'woocommerce-lead-time' ),
                'desc_tip'      => true,
                'description'   => __( 'Enter a lead time to be displayed on the product page', 'woocommerce-lead-time' ),
                'placeholder'   => ! empty( $global_lead_time ) ? $global_lead_time : '',
            )
        );
    
        echo '</div>';
    }

    /**
     * Save the lead time field
     *
     * @since 1.0.0
     */
    public function save_field( $post_id ) {
        if ( ! isset( $_POST[ '_wclt_lead_time' ] ) ) {
            return;
        }

        $product = wc_get_product( $post_id );
        $lead_time = sanitize_text_field( $_POST[ '_wclt_lead_time' ] );

        $product->update_meta_data( '_wclt_lead_time', $lead_time );
        $product->save();
    }
}