<?php

/**
 * The main plugin file for WooCommerce Lead Time.
 *
 * @wordpress-plugin
 * Plugin Name:     WooCommerce Lead Time
 * Plugin URI:      https://barn2.co.uk/wordpress-plugins/woocommerce-lead-time/
 * Description:     Provide individual and global lead times for your WooCommerce products.
 * Version:         1.0.1
 * Author:          20script
 * Author URI:      https://www.20script.ir
 * Text Domain:     woocommerce-lead-time
 * Domain Path:     /languages
 *
 * WC requires at least: 3.3
 * WC tested up to: 3.8
 *
 * Copyright:       Barn2 Media Ltd
 * License:         GNU General Public License v3.0
 * License URI:     http://www.gnu.org/licenses/gpl-3.0.html
 */
namespace Barn2\Plugin\WC_Lead_Time;

// Prevent direct file access
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Define WCLT_PLUGIN_FILE.
if ( ! defined( 'WCLT_PLUGIN_FILE' ) ) {
    define( 'WCLT_PLUGIN_FILE', __FILE__ );
}

/**
 * Includes Autoloader
 *
 * @since 1.0.0
 *
 * @param string $class The fully-qualified class name.
 * @return void
 */
spl_autoload_register( function ( $class ) {
    $prefix   = 'Barn2\\Plugin\\WC_Lead_Time';
    $base_dir = __DIR__ . '/includes/';

    $len = strlen( $prefix );
    if ( strncmp( $prefix, $class, $len ) !== 0 ) {
        return;
    }

    $relative_class = substr( $class, $len );
    $file           = $base_dir . str_replace( '\\', '/', $relative_class ) . '.php';

    if ( file_exists( $file ) ) {
        require $file;
    }
} );

/**
 * Lib Autoloader
 *
 * @since 1.0.0
 *
 * @param string $class The fully-qualified class name.
 * @return void
 */
spl_autoload_register( function ( $class ) {
    $prefix   = 'Barn2\\Lib';
    $base_dir = __DIR__ . '/lib/';

    $len = strlen( $prefix );
    if ( strncmp( $prefix, $class, $len ) !== 0 ) {
        return;
    }

    $relative_class = substr( $class, $len );
    $file           = $base_dir . str_replace( '\\', '/', $relative_class ) . '.php';

    if ( file_exists( $file ) ) {
        require $file;
    }
} );

/**
 * Initialize Plugin
 *
 * @since 1.0.0
 */
function init() {
    Plugin::get_instance();
}

add_action( 'plugins_loaded', 'Barn2\\Plugin\\WC_Lead_Time\\init' );
